@@ -14,7 +14,7 @@ import featuretools.variable_types as vt
 from featuretools.selection import remove_low_information_features
 
 from tqdm.auto import tqdm
-from tql.pipe import reduce_mem_usage
+from tql.pipe import reduce_mem_usage, cprint
 
 
 class AutoFeat(object):
@@ -36,8 +36,14 @@ class AutoFeat(object):
 
         print(self.es)
 
-    def dfs(self, target_entity, max_depth=1, features_only=True, n_jobs=1, chunk_size=None, ignore_variables=['uid']):
+    def dfs(self, target_entity=None, max_depth=1, features_only=True, n_jobs=1, chunk_size=None,
+            ignore_variables=['uid']):
         """Deep Feature Synthesis"""
+        if self.index != '__id':
+            target_entity = self.entity_id
+            cprint(f"target_entity == base_entity_id: {self.entity_id} !!!")
+        else:
+            assert target_entity is not None
 
         for col in tqdm(self.normalize_entity_cols, desc='Normalize Entity'):
             self.es.normalize_entity(self.entity_id, col, col)
@@ -47,7 +53,7 @@ class AutoFeat(object):
     def run_dfs(self, es, target_entity, max_depth, chunk_size, n_jobs, features_only, ignore_variables):
         _ = ft.dfs(
             entityset=es,
-            target_entity=target_entity,  # 具有唯一ID
+            target_entity=target_entity,  # 具有唯一ID: 不重复id的base_es或者normalize_entity生成的唯一id es
             max_depth=max_depth,
             verbose=1,
             chunk_size=chunk_size,
@@ -94,5 +100,7 @@ if __name__ == '__main__':
     }
 
     af = AutoFeat(df, 'test', type2features)
+    # af = AutoFeat(df, 'test', type2features, index='uid')  # base_entity 就是 base_entity_id
+
     af.dfs('uid')
     af.es.plot()
